@@ -24,9 +24,9 @@
 
 #include <KConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
 
 #include "docentrytraverser.h"
-#include <KLocalizedString>
 #include <ki18n_version.h>
 
 #include <prefs.h>
@@ -35,7 +35,7 @@ using namespace KHC;
 
 bool DocMetaInfo::mLoaded = false;
 
-DocMetaInfo *DocMetaInfo::mSelf = 0;
+DocMetaInfo *DocMetaInfo::mSelf = nullptr;
 
 DocMetaInfo *DocMetaInfo::self()
 {
@@ -45,14 +45,14 @@ DocMetaInfo *DocMetaInfo::self()
 
 DocMetaInfo::DocMetaInfo()
 {
-  khcDebug() << "DocMetaInfo()";
+  qCDebug(KHC_LOG) << "DocMetaInfo()";
 
   mRootEntry.setName( i18n("Top-Level Documentation") );
 }
 
 DocMetaInfo::~DocMetaInfo()
 {
-  khcDebug() << "~DocMetaInfo()";
+  qCDebug(KHC_LOG) << "~DocMetaInfo()";
 
   DocEntry::List::ConstIterator it;
   for( it = mDocEntries.constBegin(); it != mDocEntries.constEnd(); ++it )
@@ -62,15 +62,15 @@ DocMetaInfo::~DocMetaInfo()
 
   mLoaded = false;
 
-  mSelf = 0;
+  mSelf = nullptr;
 }
 
 DocEntry *DocMetaInfo::addDocEntry( const QFileInfo &fi )
 {
-  if ( !fi.exists() ) return 0;
+  if ( !fi.exists() ) return nullptr;
 
   QString extension = fi.completeSuffix();
-  QStringList extensions = extension.split( '.');
+  QStringList extensions = extension.split( QLatin1Char('.'));
   QString lang;
   if ( extensions.count() >= 2 )
   {
@@ -79,7 +79,7 @@ DocEntry *DocMetaInfo::addDocEntry( const QFileInfo &fi )
 
   if ( !lang.isEmpty() && !mLanguages.contains( lang ) )
   {
-    return 0;
+    return nullptr;
   }
 
   DocEntry *entry = new DocEntry();
@@ -100,7 +100,7 @@ DocEntry *DocMetaInfo::addDocEntry( const QFileInfo &fi )
                              *it ) );
     }
     QString indexer = entry->indexer();
-    indexer.replace( "%f", fi.absoluteFilePath() );
+    indexer.replace( QStringLiteral("%f"), fi.absoluteFilePath() );
     entry->setIndexer( indexer );
     addDocEntry( entry );
     return entry;
@@ -108,7 +108,7 @@ DocEntry *DocMetaInfo::addDocEntry( const QFileInfo &fi )
   else 
   {
     delete entry;
-    return 0;
+    return nullptr;
   }
 }
 
@@ -130,12 +130,12 @@ DocEntry::List DocMetaInfo::searchEntries() const
 
 QString DocMetaInfo::languageName( const QString &langcode )
 {
-  if ( langcode == "en" )
+  if ( langcode == QLatin1String("en") )
       return i18nc("Describes documentation entries that are in English", "English");
 
   QString cfgfile = QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral( "locale/%1/kf5_entry.desktop" ).arg( langcode ) );
 
-  khcDebug() << "-- langcode: " << langcode << " cfgfile: " << cfgfile;
+  qCDebug(KHC_LOG) << "-- langcode: " << langcode << " cfgfile: " << cfgfile;
 
   KConfig _cfg( cfgfile, KConfig::SimpleConfig );
   KConfigGroup cfg(&_cfg, "KCM Locale" );
@@ -148,11 +148,7 @@ void DocMetaInfo::scanMetaInfo( bool force )
 {
   if ( mLoaded && !force ) return;
 
-#if KI18N_VERSION >= QT_VERSION_CHECK(5, 20, 0)
   mLanguages = KLocalizedString::languages();
-#else
-  mLanguages = QLocale().uiLanguages();
-#endif
 
   QStringList::ConstIterator it;
 
@@ -160,11 +156,11 @@ void DocMetaInfo::scanMetaInfo( bool force )
 
   if ( metaInfos.isEmpty() ) 
   {
-    metaInfos = QStandardPaths::locateAll(QStandardPaths::DataLocation, "plugins", QStandardPaths::LocateDirectory);
+    metaInfos = QStandardPaths::locateAll(QStandardPaths::DataLocation, QStringLiteral("plugins"), QStandardPaths::LocateDirectory);
   }
   for( it = metaInfos.constBegin(); it != metaInfos.constEnd(); ++it)
   {
-    khcDebug() << "DocMetaInfo::scanMetaInfo(): scanning " << *it;
+    qCDebug(KHC_LOG) << "DocMetaInfo::scanMetaInfo(): scanning " << *it;
     scanMetaInfoDir( *it, &mRootEntry );
   }
 
@@ -175,11 +171,11 @@ DocEntry *DocMetaInfo::scanMetaInfoDir( const QString &dirName,
                                         DocEntry *parent )
 {
   QDir dir( dirName );
-  if ( !dir.exists() ) return 0;
+  if ( !dir.exists() ) return nullptr;
 
   foreach( const QFileInfo &fi, dir.entryInfoList(QDir::Dirs | QDir::Files | QDir::NoDotAndDotDot) ) 
   {
-    DocEntry *entry = 0;
+    DocEntry *entry = nullptr;
     if ( fi.isDir() ) 
     {
       DocEntry *dirEntry = addDirEntry( QDir( fi.absoluteFilePath() ), parent );
@@ -192,7 +188,7 @@ DocEntry *DocMetaInfo::scanMetaInfoDir( const QString &dirName,
     }
   }
 
-  return 0;
+  return nullptr;
 }
 
 DocEntry *DocMetaInfo::addDirEntry( const QDir &dir, DocEntry *parent )
@@ -241,7 +237,7 @@ void DocMetaInfo::traverseEntry( DocEntry *entry, DocEntryTraverser *traverser )
 
 void DocMetaInfo::startTraverseEntries( DocEntryTraverser *traverser )
 {
-  khcDebug() << "DocMetaInfo::startTraverseEntries()";
+  qCDebug(KHC_LOG) << "DocMetaInfo::startTraverseEntries()";
   traverser->setNotifyee( this );
   startTraverseEntry( &mRootEntry, traverser );
 }
@@ -251,13 +247,13 @@ void DocMetaInfo::startTraverseEntry( DocEntry *entry,
 {
   if ( !traverser ) 
   {
-    khcWarning() << "DocMetaInfo::startTraverseEntry(): ERROR. No Traverser.";
+    qCWarning(KHC_LOG) << "DocMetaInfo::startTraverseEntry(): ERROR. No Traverser.";
     return;
   }
 
   if ( !entry ) 
   {
-    khcWarning() << "DocMetaInfo::startTraverseEntry(): no entry.";
+    qCWarning(KHC_LOG) << "DocMetaInfo::startTraverseEntry(): no entry.";
     endTraverseEntries( traverser );
     return;
   }
@@ -282,7 +278,7 @@ void DocMetaInfo::endProcess( DocEntry *entry, DocEntryTraverser *traverser )
   } else 
   {
     DocEntry *parent = entry->parent();
-    DocEntryTraverser *parentTraverser = 0;
+    DocEntryTraverser *parentTraverser = nullptr;
     while ( parent ) {
       parentTraverser = traverser->parentTraverser();
       traverser->deleteTraverser();
@@ -305,11 +301,11 @@ void DocMetaInfo::endProcess( DocEntry *entry, DocEntryTraverser *traverser )
 
 void DocMetaInfo::endTraverseEntries( DocEntryTraverser *traverser )
 {
-  khcDebug() << "DocMetaInfo::endTraverseEntries()";
+  qCDebug(KHC_LOG) << "DocMetaInfo::endTraverseEntries()";
 
   if ( !traverser ) 
   {
-    khcDebug() << " no more traversers.";
+    qCDebug(KHC_LOG) << " no more traversers.";
     return;
   }
 
