@@ -20,29 +20,28 @@
 
 #include "navigator.h"
 
+#include <QApplication>
 #include <QDir>
 #include <QFile>
-#include <QTextStream>
-#include <QPushButton>
 #include <QHBoxLayout>
-#include <QVBoxLayout>
-#include <QTreeWidgetItemIterator>
-#include <qapplication.h>
 #include <QProgressBar>
+#include <QPushButton>
+#include <QStandardPaths>
 #include <QTabWidget>
+#include <QTextStream>
 #include <QTreeWidget>
+#include <QTreeWidgetItemIterator>
+#include <QVBoxLayout>
 
+#include <KDesktopFile>
 #include <KLineEdit>
 #include <KMessageBox>
-#include <KDesktopFile>
+#include <KProcess>
 #include <KProtocolInfo>
 #include <KServiceGroup>
 #include <KServiceTypeTrader>
-#include <KProcess>
 #include <KShell>
 
-#include <QStandardPaths>
-
 #include "navigatoritem.h"
 #include "navigatorappitem.h"
 #include "navigatorappgroupitem.h"
@@ -67,7 +66,7 @@ using namespace KHC;
 
 Navigator::Navigator( View *view, QWidget *parent )
    : QWidget( parent ),
-     mView( view ), mSelected( false ), mIndexingProc( 0 )
+     mView( view ), mSelected( false ), mIndexingProc( nullptr )
 {
     mSearchEngine = new SearchEngine( view );
     connect(mSearchEngine, &SearchEngine::searchFinished, this, &Navigator::slotSearchFinished);
@@ -83,7 +82,7 @@ Navigator::Navigator( View *view, QWidget *parent )
     searchLayout->setMargin( 6 );
 
     mSearchEdit = new KLineEdit( mSearchLineEditWidget );
-    mSearchEdit->setClearButtonShown(true);
+    mSearchEdit->setClearButtonEnabled(true);
     searchLayout->addWidget( mSearchEdit );
     connect(mSearchEdit, &KLineEdit::returnPressed, this, &Navigator::slotSearch);
     connect(mSearchEdit, &KLineEdit::textChanged, this, &Navigator::checkSearchButton);
@@ -169,7 +168,7 @@ void Navigator::insertPlugins()
 
 void Navigator::insertParentAppDocs( const QString &name, NavigatorItem *topItem )
 {
-  khcDebug() << "Requested plugin documents for ID " << name;
+  qCDebug(KHC_LOG) << "Requested plugin documents for ID " << name;
 
   KServiceGroup::Ptr grp = KServiceGroup::childGroup( name );
   if ( !grp )
@@ -188,18 +187,18 @@ void Navigator::insertParentAppDocs( const QString &name, NavigatorItem *topItem
 
 void Navigator::insertKCMDocs( const QString &name, NavigatorItem *topItem, const QString &type )
 {
-  khcDebug() << "Requested KCM documents for ID" << name;
-  QString systemsettingskontrolconstraint = "[X-KDE-System-Settings-Parent-Category] != ''";
-  QString konquerorcontrolconstraint = "[X-KDE-PluginKeyword] == 'khtml_general'\
+  qCDebug(KHC_LOG) << "Requested KCM documents for ID" << name;
+  QString systemsettingskontrolconstraint = QStringLiteral("[X-KDE-System-Settings-Parent-Category] != ''");
+  QString konquerorcontrolconstraint = QStringLiteral("[X-KDE-PluginKeyword] == 'khtml_general'\
                                      or [X-KDE-PluginKeyword] == 'performance'\
-                                     or [X-KDE-PluginKeyword] == 'bookmarks'";
-  QString filemanagercontrolconstraint = "[X-KDE-PluginKeyword] == 'behavior'\
+                                     or [X-KDE-PluginKeyword] == 'bookmarks'");
+  QString filemanagercontrolconstraint = QStringLiteral("[X-KDE-PluginKeyword] == 'behavior'\
                                        or [X-KDE-PluginKeyword] == 'dolphinviewmodes'\
                                        or [X-KDE-PluginKeyword] == 'dolphinnavigation'\
                                        or [X-KDE-PluginKeyword] == 'dolphinservices'\
                                        or [X-KDE-PluginKeyword] == 'dolphingeneral'\
-                                       or [X-KDE-PluginKeyword] == 'trash'";
-  QString browsercontrolconstraint = "[X-KDE-PluginKeyword] == 'khtml_behavior'\
+                                       or [X-KDE-PluginKeyword] == 'trash'");
+  QString browsercontrolconstraint = QStringLiteral("[X-KDE-PluginKeyword] == 'khtml_behavior'\
                                    or [X-KDE-PluginKeyword] == 'proxy'\
                                    or [X-KDE-PluginKeyword] == 'khtml_appearance'\
                                    or [X-KDE-PluginKeyword] == 'khtml_filter'\
@@ -207,26 +206,26 @@ void Navigator::insertKCMDocs( const QString &name, NavigatorItem *topItem, cons
                                    or [X-KDE-PluginKeyword] == 'cookie'\
                                    or [X-KDE-PluginKeyword] == 'useragent'\
                                    or [X-KDE-PluginKeyword] == 'khtml_java_js'\
-                                   or [X-KDE-PluginKeyword] == 'khtml_plugins'";
+                                   or [X-KDE-PluginKeyword] == 'khtml_plugins'");
 /* missing in browsercontrolconstraint
 History                 no X-KDE-PluginKeyword in kcmhistory.desktop
 */
-  QString othercontrolconstraint = "[X-KDE-PluginKeyword] == 'cgi'";
+  QString othercontrolconstraint = QStringLiteral("[X-KDE-PluginKeyword] == 'cgi'");
 
   KService::List list;
 
-  if ( type == QString("kcontrol") ) {
-    list = KServiceTypeTrader::self()->query( "KCModule", systemsettingskontrolconstraint );
-  } else if ( type == QString("konquerorcontrol") ) {
-    list = KServiceTypeTrader::self()->query( "KCModule", konquerorcontrolconstraint );
-  } else if ( type == QString("browsercontrol") ) {
-    list = KServiceTypeTrader::self()->query( "KCModule", browsercontrolconstraint );
-  } else if ( type == QString("filemanagercontrol") ) {
-    list = KServiceTypeTrader::self()->query( "KCModule", filemanagercontrolconstraint );
-  } else if ( type == QString("othercontrol") ) {
-    list = KServiceTypeTrader::self()->query( "KCModule", othercontrolconstraint );
-  } else if ( type == QString("kinfocenter") ) {
-    list = KServiceTypeTrader::self()->query( "KCModule", "[X-KDE-ParentApp] == 'kinfocenter'" );
+  if ( type == QLatin1String("kcontrol") ) {
+    list = KServiceTypeTrader::self()->query( QStringLiteral("KCModule"), systemsettingskontrolconstraint );
+  } else if ( type == QLatin1String("konquerorcontrol") ) {
+    list = KServiceTypeTrader::self()->query( QStringLiteral("KCModule"), konquerorcontrolconstraint );
+  } else if ( type == QLatin1String("browsercontrol") ) {
+    list = KServiceTypeTrader::self()->query( QStringLiteral("KCModule"), browsercontrolconstraint );
+  } else if ( type == QLatin1String("filemanagercontrol") ) {
+    list = KServiceTypeTrader::self()->query( QStringLiteral("KCModule"), filemanagercontrolconstraint );
+  } else if ( type == QLatin1String("othercontrol") ) {
+    list = KServiceTypeTrader::self()->query( QStringLiteral("KCModule"), othercontrolconstraint );
+  } else if ( type == QLatin1String("kinfocenter") ) {
+    list = KServiceTypeTrader::self()->query( QStringLiteral("KCModule"), QStringLiteral("[X-KDE-ParentApp] == 'kinfocenter'") );
   }
 
   for ( KService::List::const_iterator it = list.constBegin(); it != list.constEnd(); ++it )
@@ -240,12 +239,12 @@ History                 no X-KDE-PluginKeyword in kcmhistory.desktop
 
 void Navigator::insertIOSlaveDocs( const QString &name, NavigatorItem *topItem )
 {
-  khcDebug() << "Requested IOSlave documents for ID" << name;
+  qCDebug(KHC_LOG) << "Requested IOSlave documents for ID" << name;
 
   QStringList list = KProtocolInfo::protocols();
   list.sort();
 
-  NavigatorItem *prevItem = 0;
+  NavigatorItem *prevItem = nullptr;
   for ( QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it )
   {
     QString docPath = KProtocolInfo::docPath(*it);
@@ -254,7 +253,7 @@ void Navigator::insertIOSlaveDocs( const QString &name, NavigatorItem *topItem )
       // First parameter is ignored if second is an absolute path
       QUrl url(QStringLiteral("help:/") + docPath);
       QString icon = KProtocolInfo::icon(*it);
-      if ( icon.isEmpty() ) icon = "text-plain";
+      if ( icon.isEmpty() ) icon = QStringLiteral("text-plain");
       DocEntry *entry = new DocEntry( *it, url.url(), icon );
       NavigatorItem *item = new NavigatorAppItem( entry, topItem, prevItem );
       prevItem = item;
@@ -272,7 +271,7 @@ void Navigator::createItemFromDesktopFile( NavigatorItem *topItem,
       // First parameter is ignored if second is an absolute path
       QUrl url(QStringLiteral("help:/") + docPath);
       QString icon = desktopFile.readIcon();
-      if ( icon.isEmpty() ) icon = "text-plain";
+      if ( icon.isEmpty() ) icon = QStringLiteral("text-plain");
       DocEntry *entry = new DocEntry( desktopFile.readName(), url.url(), icon );
       NavigatorItem *item = new NavigatorAppItem( entry, topItem );
       item->setAutoDeleteDocEntry( true );
@@ -293,9 +292,9 @@ void Navigator::insertScrollKeeperDocs( NavigatorItem *topItem )
 
 void Navigator::selectItem( const QUrl &url )
 {
-  khcDebug() << "Navigator::selectItem(): " << url.url();
+  qCDebug(KHC_LOG) << "Navigator::selectItem(): " << url.url();
 
-  if ( url.url() == "khelpcenter:home" ) {
+  if ( url.url() == QLatin1String("khelpcenter:home") ) {
     clearSelection();
     return;
   }
@@ -306,7 +305,7 @@ void Navigator::selectItem( const QUrl &url )
   QUrl alternativeURL = url;
   if (url.hasFragment())
   {
-     alternativeURL.setQuery("anchor="+url.fragment());
+     alternativeURL.setQuery(QStringLiteral("anchor=")+url.fragment());
      alternativeURL.setFragment(QString());
   }
 
@@ -316,7 +315,7 @@ void Navigator::selectItem( const QUrl &url )
   if ( item && mSelected ) {
     QUrl currentURL ( item->entry()->url() );
     if ( (currentURL == url) || (currentURL == alternativeURL) ) {
-      khcDebug() << "URL already shown.";
+      qCDebug(KHC_LOG) << "URL already shown.";
       return;
     }
   }
@@ -367,7 +366,7 @@ void Navigator::slotItemSelected( QTreeWidgetItem *currentItem )
 
   NavigatorItem *item = static_cast<NavigatorItem *>( currentItem );
 
-  khcDebug() << item->entry()->name();
+  qCDebug(KHC_LOG) << item->entry()->name();
 
   item->setExpanded( !item->isExpanded() );
 
@@ -375,7 +374,7 @@ void Navigator::slotItemSelected( QTreeWidgetItem *currentItem )
 
   
   
-  if ( url.scheme() == "khelpcenter" ) {
+  if ( url.scheme() == QLatin1String("khelpcenter") ) {
       mView->closeUrl();
       History::self().updateCurrentEntry( mView );
       History::self().createEntry();
@@ -400,9 +399,9 @@ void Navigator::slotItemCollapsed( QTreeWidgetItem *item )
 
 void Navigator::openInternalUrl( const QUrl &url )
 {
-  if ( url.url() == "khelpcenter:home" ) {
+  if ( url.url() == QLatin1String("khelpcenter:home") ) {
     clearSelection();
-    showOverview( 0, url );
+    showOverview( nullptr, url );
     return;
   }
 
@@ -491,7 +490,7 @@ QString Navigator::createChildrenList( QTreeWidgetItem *child, int level )
 void Navigator::slotSearch()
 {
   
-  khcDebug() << "Navigator::slotSearch()";
+  qCDebug(KHC_LOG) << "Navigator::slotSearch()";
 
   if ( mIndexingProc ) return;
 
@@ -502,8 +501,8 @@ void Navigator::slotSearch()
   int pages = mSearchWidget->pages();
   QStringList scope = mSearchWidget->scope();
 
-  khcDebug() << "Navigator::slotSearch() words: " << words;
-  khcDebug() << "Navigator::slotSearch() scope: " << scope;
+  qCDebug(KHC_LOG) << "Navigator::slotSearch() words: " << words;
+  qCDebug(KHC_LOG) << "Navigator::slotSearch() scope: " << scope;
 
   if ( words.isEmpty() || scope.isEmpty() ) return;
 
@@ -523,7 +522,7 @@ void Navigator::slotSearch()
 void Navigator::slotShowSearchResult( const QString &url )
 {
   QString u = url;
-  u.replace( "%k", mSearchEdit->text() );
+  u.replace( QStringLiteral("%k"), mSearchEdit->text() );
 
   emit itemSelected( u );
 }
@@ -533,7 +532,7 @@ void Navigator::slotSearchFinished()
   mSearchButton->setEnabled(true);
   QApplication::restoreOverrideCursor();
 
-  khcDebug() << "Search finished.";
+  qCDebug(KHC_LOG) << "Search finished.";
 }
 
 void Navigator::checkSearchButton()
@@ -633,12 +632,12 @@ void Navigator::slotDoIndexWork()
     return slotDoIndexWork();
   }
   if ( !handler->checkPaths( &error ) ) {
-    khcWarning() << "Indexing path error for" << entry->name() << ":" << error;
+    qCWarning(KHC_LOG) << "Indexing path error for" << entry->name() << ":" << error;
     return slotDoIndexWork();
   }
   QString indexer = handler->indexCommand( entry->identifier() );
   if ( indexer.isEmpty() ) {
-    khcWarning() << "Empty indexer for" << entry->identifier() << entry->documentType();
+    qCWarning(KHC_LOG) << "Empty indexer for" << entry->identifier() << entry->documentType();
     return slotDoIndexWork();
   }
 
@@ -647,10 +646,10 @@ void Navigator::slotDoIndexWork()
   indexer.replace( QLatin1String( "%i" ), entry->identifier() );
   indexer.replace( QLatin1String( "%d" ), indexDir );
   indexer.replace( QLatin1String( "%p" ), entry->url() );
-  khcDebug() << "Indexer:" << indexer;
+  qCDebug(KHC_LOG) << "Indexer:" << indexer;
 
   if ( !QDir().mkpath( indexDir ) ) {
-    khcWarning() << "cannot create the directory:" << indexDir;
+    qCWarning(KHC_LOG) << "cannot create the directory:" << indexDir;
     return slotDoIndexWork();
   }
 
@@ -658,15 +657,14 @@ void Navigator::slotDoIndexWork()
 
   *mIndexingProc << KShell::splitArgs( indexer );
 
-  connect( mIndexingProc, SIGNAL( finished( int, QProcess::ExitStatus) ),
-           SLOT( slotProcessExited( int, QProcess::ExitStatus) ) );
+  connect(mIndexingProc, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished), this, &Navigator::slotProcessExited);
 
   mIndexingProc->start();
 
   if ( !mIndexingProc->waitForStarted() )  {
-    khcWarning() << "Unable to start command" << indexer;
+    qCWarning(KHC_LOG) << "Unable to start command" << indexer;
     delete mIndexingProc;
-    mIndexingProc = 0;
+    mIndexingProc = nullptr;
     return slotDoIndexWork();
   }
 }
@@ -674,16 +672,16 @@ void Navigator::slotDoIndexWork()
 void Navigator::slotProcessExited( int exitCode, QProcess::ExitStatus exitStatus )
 {
   if ( exitStatus != QProcess::NormalExit ) {
-    khcWarning() << "Process failed";
-    khcWarning() << "stdout output:" << mIndexingProc->readAllStandardOutput();
-    khcWarning() << "stderr output:" << mIndexingProc->readAllStandardError();
+    qCWarning(KHC_LOG) << "Process failed";
+    qCWarning(KHC_LOG) << "stdout output:" << mIndexingProc->readAllStandardOutput();
+    qCWarning(KHC_LOG) << "stderr output:" << mIndexingProc->readAllStandardError();
   } else if ( exitCode != 0 ) {
-    khcWarning() << "running" << mIndexingProc->program() << "failed with exitCode" << exitCode;
-    khcWarning() << "stdout output:" << mIndexingProc->readAllStandardOutput();
-    khcWarning() << "stderr output:" << mIndexingProc->readAllStandardError();
+    qCWarning(KHC_LOG) << "running" << mIndexingProc->program() << "failed with exitCode" << exitCode;
+    qCWarning(KHC_LOG) << "stdout output:" << mIndexingProc->readAllStandardOutput();
+    qCWarning(KHC_LOG) << "stderr output:" << mIndexingProc->readAllStandardError();
   }
   delete mIndexingProc;
-  mIndexingProc = 0;
+  mIndexingProc = nullptr;
 
   slotDoIndexWork();
 }
