@@ -24,28 +24,28 @@
 #include "view.h"
 #include "khc_debug.h"
 
-#include <QUrl>
 #include <QMetaObject>
+#include <QUrl>
 
 using namespace KHC;
 
 NavigatorAppItem::NavigatorAppItem( DocEntry *entry, QTreeWidgetItem *parent )
   : NavigatorItem( entry, parent ),
-    mToc( 0 )
+    mToc( nullptr )
 {
 }
 
 NavigatorAppItem::NavigatorAppItem( DocEntry *entry, QTreeWidget *parent,
                   QTreeWidgetItem *after )
   : NavigatorItem( entry, parent, after ),
-    mToc( 0 )
+    mToc( nullptr )
 {
 }
 
 NavigatorAppItem::NavigatorAppItem( DocEntry *entry, QTreeWidgetItem *parent,
                   QTreeWidgetItem *after )
   : NavigatorItem( entry, parent, after ),
-    mToc( 0 )
+    mToc( nullptr )
 {
 }
 
@@ -71,7 +71,7 @@ void NavigatorAppItem::scheduleTOCBuild()
   if ( url.scheme() == QLatin1String( "help" ) ) {
     mToc = new TOC( this );
 
-    khcDebug() << "Trying to build TOC for" << entry()->name();
+    qCDebug(KHC_LOG) << "Trying to build TOC for" << entry()->name();
     mToc->setApplication( url.toString( QUrl::RemoveScheme | QUrl::RemoveFilename | QUrl::StripTrailingSlash ) );
     QString doc = View::langLookup( url.path() );
     // Enforce the original .docbook version, in case langLookup returns a
@@ -81,7 +81,7 @@ void NavigatorAppItem::scheduleTOCBuild()
       if ( pos >= 0 ) {
         doc.replace( pos, 5, QLatin1String( ".docbook" ) );
       }
-      khcDebug() << "doc =" << doc;
+      qCDebug(KHC_LOG) << "doc =" << doc;
 
       mToc->build( doc );
       // ensure the newly populated item is expanded
